/**************************************************************** 
 * Description: 
 功能分析：
这段代码实现了经典的汉诺塔问题，其中有三个柱子（编号分别为1, 2, 3），以及 n 个盘子，
初始时所有盘子都在第一个柱子上。汉诺塔问题的目标是将所有盘子从第一个柱子移动到第三个柱子，
遵循以下规则：
一次只能移动一个盘子。
每次移动时，一个盘子只能放在另一个柱子上。
大盘子不能放在小盘子上面。
具体流程：
函数 fun 通过递归的方式来计算从 fromPos 移动 n 个盘子到 toPos 所需的步骤数。
递归过程中，首先找出既不是 fromPos 也不是 toPos 的辅助柱子 t。
然后，递归地将 n-1 个盘子从 fromPos 移动到辅助柱 t，接着将最大的盘子从 fromPos 移动到 toPos，最后将 n-1 个盘子从 t 移动到 toPos。
通过递归的调用，最终可以求出将 n 个盘子从柱子1移动到柱子3所需的最小步骤数。
当用户输入盘子数量 n 后，程序会输出将所有盘子从柱子1移动到柱子3所需的最小步骤数。
 * Author: Alex Li
 * Date: 2024-08-21 22:40:30
 * LastEditTime: 2024-08-21 22:40:46
****************************************************************/
#include <iostream>
using namespace std;

// 递归函数，计算将n个盘子从fromPos移动到toPos所需的步骤数
int fun(int n, int fromPos, int toPos)
{
    int t, tot;
    // 基本情况：如果没有盘子需要移动，返回0（无操作）
    if(n == 0) return 0;
    
    // 找到辅助柱t，它既不是起始柱fromPos也不是目标柱toPos
    for(t = 1; t <= 3; t++)
        if(t != fromPos && t != toPos) break;
    
    tot = 0;
    // 递归地将n-1个盘子从起始柱fromPos移动到辅助柱t
    tot += fun(n-1, fromPos, t);
    
    // 增加一步将最大的盘子从起始柱fromPos移动到目标柱toPos
    tot++;
    
    // 递归地将n-1个盘子从辅助柱t移动到目标柱toPos
    tot += fun(n-1, t, toPos);
    
    return tot;
}

int main()
{
    int n;
    // 输入盘子数量n
    cin >> n;
    // 输出将n个盘子从柱子1移动到柱子3所需的最少步骤数
    cout << fun(n, 1, 3) << endl;
    return 0;
}
